@@ -42,7 +42,7 @@ use Class::ParmList qw(parse_parms);
 use constant AUTO => 1; # auto extract and parse?
 use constant CLEAN => 1; # auto unlink() files?
 
-use Data::Dumper;
+our $VERSION = '1.02';
 
 =head1 OBJECT METHODS
 
